@@ -1,6 +1,6 @@
 from .drive import *
 from .filesystem import *
-from .linux_volume import *
+from .linux_device import *
 from .partition import *
 from .mounted_volume import *
 from .logical_volume import *
