@@ -66,3 +66,15 @@ class MountedVolumeIndex(SearchIndex):
         ('mount_point', 100),
         ('description', 100),
     )
+
+
+@register_search
+class LinuxDeviceIndex(SearchIndex):
+    model = models.LinuxDevice
+    fields = (
+        ('device', 100),
+        ('type', 100),
+        ('size', 100),
+        ('content_type', 100),
+        ('object_id', 100),
+    )
\ No newline at end of file
